==> cucumber-scala-1.1.1-sources.jar: cucumber/api/scala/I18n.scala <==
package cucumber.api.scala


trait AR {
  this: ScalaDsl =>

  val اذاً = new Step("اذاً")

  val بفرض = new Step("بفرض")

  val ثم = new Step("ثم")

  val عندما = new Step("عندما")

  val لكن = new Step("لكن")

  val متى = new Step("متى")

  val و = new Step("و")

}

trait BG {
  this: ScalaDsl =>

  val Дадено = new Step("Дадено")

  val И = new Step("И")

  val Когато = new Step("Когато")

  val Но = new Step("Но")

  val То = new Step("То")

}

trait BM {
  this: ScalaDsl =>

  val Apabila = new Step("Apabila")

  val Bagi = new Step("Bagi")

  val Dan = new Step("Dan")

  val Kemudian = new Step("Kemudian")

  val Tetapi = new Step("Tetapi")

}

trait CA {
  this: ScalaDsl =>

  val Aleshores = new Step("Aleshores")

  val Atesa = new Step("Atesa")

  val Atès = new Step("Atès")

  val Cal = new Step("Cal")

  val Donada = new Step("Donada")

  val Donat = new Step("Donat")

  val I = new Step("I")

  val Però = new Step("Però")

  val Quan = new Step("Quan")

}

trait CS {
  this: ScalaDsl =>

  val A = new Step("A")

  val Ale = new Step("Ale")

  val Ataké = new Step("Ataké")

  val Když = new Step("Když")

  val Pak = new Step("Pak")

  val Pokud = new Step("Pokud")

  val Zapředpokladu = new Step("Zapředpokladu")

}

trait CY_GB {
  this: ScalaDsl =>

  val A = new Step("A")

  val Anrhegediga = new Step("Anrhegediga")

  val Ond = new Step("Ond")

  val Pryd = new Step("Pryd")

  val Yna = new Step("Yna")

}

trait DA {
  this: ScalaDsl =>

  val Givet = new Step("Givet")

  val Men = new Step("Men")

  val Når = new Step("Når")

  val Og = new Step("Og")

  val Så = new Step("Så")

}

trait DE {
  this: ScalaDsl =>

  val Aber = new Step("Aber")

  val Angenommen = new Step("Angenommen")

  val Dann = new Step("Dann")

  val Gegebensei = new Step("Gegebensei")

  val Und = new Step("Und")

  val Wenn = new Step("Wenn")

}

trait EN {
  this: ScalaDsl =>

  val And = new Step("And")

  val But = new Step("But")

  val Given = new Step("Given")

  val Then = new Step("Then")

  val When = new Step("When")

}

trait EN_SCOUSE {
  this: ScalaDsl =>

  val An = new Step("An")

  val Buh = new Step("Buh")

  val Denyousegotta = new Step("Denyousegotta")

  val Dun = new Step("Dun")

  val Givun = new Step("Givun")

  val Wun = new Step("Wun")

  val Youseknowlikewhen = new Step("Youseknowlikewhen")

  val Youseknowwhenyousegot = new Step("Youseknowwhenyousegot")

}

trait EN_AU {
  this: ScalaDsl =>

  val ButattheendofthedayIreckon = new Step("ButattheendofthedayIreckon")

  val Itsjustunbelievable = new Step("Itsjustunbelievable")

  val Tooright = new Step("Tooright")

  val Yeahnah = new Step("Yeahnah")

  val Yknow = new Step("Yknow")

}

trait EN_LOL {
  this: ScalaDsl =>

  val AN = new Step("AN")

  val BUT = new Step("BUT")

  val DEN = new Step("DEN")

  val ICANHAZ = new Step("ICANHAZ")

  val WEN = new Step("WEN")

}

trait EN_PIRATE {
  this: ScalaDsl =>

  val Avast = new Step("Avast")

  val Aye = new Step("Aye")

  val Blimey = new Step("Blimey")

  val Gangway = new Step("Gangway")

  val Letgoandhaul = new Step("Letgoandhaul")

}

trait EN_TX {
  this: ScalaDsl =>

  val Andyall = new Step("Andyall")

  val Butyall = new Step("Butyall")

  val Givenyall = new Step("Givenyall")

  val Thenyall = new Step("Thenyall")

  val Whenyall = new Step("Whenyall")

}

trait EO {
  this: ScalaDsl =>

  val Do = new Step("Do")

  val Donitaĵo = new Step("Donitaĵo")

  val Kaj = new Step("Kaj")

  val Se = new Step("Se")

  val Sed = new Step("Sed")

}

trait ES {
  this: ScalaDsl =>

  val Cuando = new Step("Cuando")

  val Dada = new Step("Dada")

  val Dadas = new Step("Dadas")

  val Dado = new Step("Dado")

  val Dados = new Step("Dados")

  val Entonces = new Step("Entonces")

  val Pero = new Step("Pero")

  val Y = new Step("Y")

}

trait ET {
  this: ScalaDsl =>

  val Eeldades = new Step("Eeldades")

  val Ja = new Step("Ja")

  val Kui = new Step("Kui")

  val Kuid = new Step("Kuid")

  val Siis = new Step("Siis")

}

trait FA {
  this: ScalaDsl =>

  val آنگاه = new Step("آنگاه")

  val اما = new Step("اما")

  val بافرض = new Step("بافرض")

  val هنگامی = new Step("هنگامی")

  val و = new Step("و")

}

trait FI {
  this: ScalaDsl =>

  val Ja = new Step("Ja")

  val Kun = new Step("Kun")

  val Mutta = new Step("Mutta")

  val Niin = new Step("Niin")

  val Oletetaan = new Step("Oletetaan")

}

trait FR {
  this: ScalaDsl =>

  val Alors = new Step("Alors")

  val Et = new Step("Et")

  val Etantdonné = new Step("Etantdonné")

  val Etantdonnée = new Step("Etantdonnée")

  val Etantdonnées = new Step("Etantdonnées")

  val Etantdonnés = new Step("Etantdonnés")

  val Lorsqu = new Step("Lorsqu")

  val Lorsque = new Step("Lorsque")

  val Mais = new Step("Mais")

  val Quand = new Step("Quand")

  val Soit = new Step("Soit")

  val Étantdonné = new Step("Étantdonné")

  val Étantdonnée = new Step("Étantdonnée")

  val Étantdonnées = new Step("Étantdonnées")

  val Étantdonnés = new Step("Étantdonnés")

}

trait HE {
  this: ScalaDsl =>

  val אבל = new Step("אבל")

  val אז = new Step("אז")

  val אזי = new Step("אזי")

  val בהינתן = new Step("בהינתן")

  val וגם = new Step("וגם")

  val כאשר = new Step("כאשר")

}

trait HR {
  this: ScalaDsl =>

  val Ali = new Step("Ali")

  val I = new Step("I")

  val Kad = new Step("Kad")

  val Kada = new Step("Kada")

  val Onda = new Step("Onda")

  val Zadan = new Step("Zadan")

  val Zadani = new Step("Zadani")

  val Zadano = new Step("Zadano")

}

trait HU {
  this: ScalaDsl =>

  val Adott = new Step("Adott")

  val Akkor = new Step("Akkor")

  val Amennyiben = new Step("Amennyiben")

  val Amikor = new Step("Amikor")

  val De = new Step("De")

  val Ha = new Step("Ha")

  val Majd = new Step("Majd")

  val És = new Step("És")

}

trait ID {
  this: ScalaDsl =>

  val Dan = new Step("Dan")

  val Dengan = new Step("Dengan")

  val Ketika = new Step("Ketika")

  val Maka = new Step("Maka")

  val Tapi = new Step("Tapi")

}

trait IS {
  this: ScalaDsl =>

  val Ef = new Step("Ef")

  val En = new Step("En")

  val Og = new Step("Og")

  val Þegar = new Step("Þegar")

  val Þá = new Step("Þá")

}

trait IT {
  this: ScalaDsl =>

  val Allora = new Step("Allora")

  val Data = new Step("Data")

  val Date = new Step("Date")

  val Dati = new Step("Dati")

  val Dato = new Step("Dato")

  val E = new Step("E")

  val Ma = new Step("Ma")

  val Quando = new Step("Quando")

}

trait JA {
  this: ScalaDsl =>

  val かつ = new Step("かつ")

  val しかし = new Step("しかし")

  val ただし = new Step("ただし")

  val ならば = new Step("ならば")

  val もし = new Step("もし")

  val 但し = new Step("但し")

  val 前提 = new Step("前提")

}

trait KO {
  this: ScalaDsl =>

  val 그러면 = new Step("그러면")

  val 그리고 = new Step("그리고")

  val 단 = new Step("단")

  val 만약 = new Step("만약")

  val 만일 = new Step("만일")

  val 먼저 = new Step("먼저")

  val 조건 = new Step("조건")

  val 하지만 = new Step("하지만")

}

trait LT {
  this: ScalaDsl =>

  val Bet = new Step("Bet")

  val Duota = new Step("Duota")

  val Ir = new Step("Ir")

  val Kai = new Step("Kai")

  val Tada = new Step("Tada")

}

trait LU {
  this: ScalaDsl =>

  val a = new Step("a")

  val an = new Step("an")

  val awer = new Step("awer")

  val dann = new Step("dann")

  val mä = new Step("mä")

  val ugeholl = new Step("ugeholl")

  val wann = new Step("wann")

}

trait LV {
  this: ScalaDsl =>

  val Bet = new Step("Bet")

  val Ja = new Step("Ja")

  val Kad = new Step("Kad")

  val Tad = new Step("Tad")

  val Un = new Step("Un")

}

trait NL {
  this: ScalaDsl =>

  val Als = new Step("Als")

  val Dan = new Step("Dan")

  val En = new Step("En")

  val Gegeven = new Step("Gegeven")

  val Maar = new Step("Maar")

  val Stel = new Step("Stel")

}

trait NO {
  this: ScalaDsl =>

  val Gitt = new Step("Gitt")

  val Men = new Step("Men")

  val Når = new Step("Når")

  val Og = new Step("Og")

  val Så = new Step("Så")

}

trait PL {
  this: ScalaDsl =>

  val Ale = new Step("Ale")

  val Gdy = new Step("Gdy")

  val I = new Step("I")

  val Jeśli = new Step("Jeśli")

  val Jeżeli = new Step("Jeżeli")

  val Kiedy = new Step("Kiedy")

  val Mając = new Step("Mając")

  val Oraz = new Step("Oraz")

  val Wtedy = new Step("Wtedy")

  val Zakładając = new Step("Zakładając")

}

trait PT {
  this: ScalaDsl =>

  val Dada = new Step("Dada")

  val Dadas = new Step("Dadas")

  val Dado = new Step("Dado")

  val Dados = new Step("Dados")

  val E = new Step("E")

  val Entao = new Step("Entao")

  val Então = new Step("Então")

  val Mas = new Step("Mas")

  val Quando = new Step("Quando")

}

trait RO {
  this: ScalaDsl =>

  val Atunci = new Step("Atunci")

  val Cand = new Step("Cand")

  val Când = new Step("Când")

  val Dar = new Step("Dar")

  val Datefiind = new Step("Datefiind")

  val Datfiind = new Step("Datfiind")

  val Datifiind = new Step("Datifiind")

  val Daţifiind = new Step("Daţifiind")

  val Dațifiind = new Step("Dațifiind")

  val Si = new Step("Si")

  val Şi = new Step("Şi")

  val Și = new Step("Și")

}

trait RU {
  this: ScalaDsl =>

  val А = new Step("А")

  val Дано = new Step("Дано")

  val Допустим = new Step("Допустим")

  val Если = new Step("Если")

  val И = new Step("И")

  val Когда = new Step("Когда")

  val Ктомуже = new Step("Ктомуже")

  val Но = new Step("Но")

  val Пусть = new Step("Пусть")

  val Также = new Step("Также")

  val То = new Step("То")

  val Тогда = new Step("Тогда")

}

trait SK {
  this: ScalaDsl =>

  val A = new Step("A")

  val Ale = new Step("Ale")

  val Keď = new Step("Keď")

  val Pokiaľ = new Step("Pokiaľ")

  val Tak = new Step("Tak")

}

trait SR_CYRL {
  this: ScalaDsl =>

  val Али = new Step("Али")

  val Задате = new Step("Задате")

  val Задати = new Step("Задати")

  val Задато = new Step("Задато")

  val И = new Step("И")

  val Кад = new Step("Кад")

  val Када = new Step("Када")

  val Онда = new Step("Онда")

}

trait SR_LATN {
  this: ScalaDsl =>

  val Ali = new Step("Ali")

  val I = new Step("I")

  val Kad = new Step("Kad")

  val Kada = new Step("Kada")

  val Onda = new Step("Onda")

  val Zadate = new Step("Zadate")

  val Zadato = new Step("Zadato")

  val Zatati = new Step("Zatati")

}

trait SV {
  this: ScalaDsl =>

  val Givet = new Step("Givet")

  val Men = new Step("Men")

  val När = new Step("När")

  val Och = new Step("Och")

  val Så = new Step("Så")

}

trait TR {
  this: ScalaDsl =>

  val Ama = new Step("Ama")

  val Diyelimki = new Step("Diyelimki")

  val Eğerki = new Step("Eğerki")

  val Fakat = new Step("Fakat")

  val Ozaman = new Step("Ozaman")

  val Ve = new Step("Ve")

}

trait UK {
  this: ScalaDsl =>

  val І = new Step("І")

  val Але = new Step("Але")

  val Атакож = new Step("Атакож")

  val Дано = new Step("Дано")

  val Коли = new Step("Коли")

  val Нехай = new Step("Нехай")

  val Припустимо = new Step("Припустимо")

  val Припустимощо = new Step("Припустимощо")

  val Та = new Step("Та")

  val То = new Step("То")

  val Тоді = new Step("Тоді")

  val Якщо = new Step("Якщо")

}

trait UZ {
  this: ScalaDsl =>

  val Агар = new Step("Агар")

  val Аммо = new Step("Аммо")

  val Бирок = new Step("Бирок")

  val Ва = new Step("Ва")

  val Лекин = new Step("Лекин")

  val Унда = new Step("Унда")

}

trait VI {
  this: ScalaDsl =>

  val Biết = new Step("Biết")

  val Cho = new Step("Cho")

  val Khi = new Step("Khi")

  val Nhưng = new Step("Nhưng")

  val Thì = new Step("Thì")

  val Và = new Step("Và")

}

trait ZH_CN {
  this: ScalaDsl =>

  val 但是 = new Step("但是")

  val 假如 = new Step("假如")

  val 假定 = new Step("假定")

  val 假设 = new Step("假设")

  val 同时 = new Step("同时")

  val 并且 = new Step("并且")

  val 当 = new Step("当")

  val 而且 = new Step("而且")

  val 那么 = new Step("那么")

}

trait ZH_TW {
  this: ScalaDsl =>

  val 並且 = new Step("並且")

  val 但是 = new Step("但是")

  val 假如 = new Step("假如")

  val 假定 = new Step("假定")

  val 假設 = new Step("假設")

  val 同時 = new Step("同時")

  val 當 = new Step("當")

  val 而且 = new Step("而且")

  val 那麼 = new Step("那麼")

}

==> cucumber-scala-1.1.2-sources.jar: cucumber/api/scala/I18n.scala <==
package cucumber.api.scala


trait AR {
  this: ScalaDsl =>

  val اذاً = new Step("اذاً")

  val بفرض = new Step("بفرض")

  val ثم = new Step("ثم")

  val عندما = new Step("عندما")

  val لكن = new Step("لكن")

  val متى = new Step("متى")

  val و = new Step("و")

}

trait BG {
  this: ScalaDsl =>

  val Дадено = new Step("Дадено")

  val И = new Step("И")

  val Когато = new Step("Когато")

  val Но = new Step("Но")

  val То = new Step("То")

}

trait BM {
  this: ScalaDsl =>

  val Apabila = new Step("Apabila")

  val Bagi = new Step("Bagi")

  val Dan = new Step("Dan")

  val Kemudian = new Step("Kemudian")

  val Tetapi = new Step("Tetapi")

}

trait CA {
  this: ScalaDsl =>

  val Aleshores = new Step("Aleshores")

  val Atesa = new Step("Atesa")

  val Atès = new Step("Atès")

  val Cal = new Step("Cal")

  val Donada = new Step("Donada")

  val Donat = new Step("Donat")

  val I = new Step("I")

  val Però = new Step("Però")

  val Quan = new Step("Quan")

}

trait CS {
  this: ScalaDsl =>

  val A = new Step("A")

  val Ale = new Step("Ale")

  val Ataké = new Step("Ataké")

  val Když = new Step("Když")

  val Pak = new Step("Pak")

  val Pokud = new Step("Pokud")

  val Zapředpokladu = new Step("Zapředpokladu")

}

trait CY_GB {
  this: ScalaDsl =>

  val A = new Step("A")

  val Anrhegediga = new Step("Anrhegediga")

  val Ond = new Step("Ond")

  val Pryd = new Step("Pryd")

  val Yna = new Step("Yna")

}

trait DA {
  this: ScalaDsl =>

  val Givet = new Step("Givet")

  val Men = new Step("Men")

  val Når = new Step("Når")

  val Og = new Step("Og")

  val Så = new Step("Så")

}

trait DE {
  this: ScalaDsl =>

  val Aber = new Step("Aber")

  val Angenommen = new Step("Angenommen")

  val Dann = new Step("Dann")

  val Gegebensei = new Step("Gegebensei")

  val Und = new Step("Und")

  val Wenn = new Step("Wenn")

}

trait EN {
  this: ScalaDsl =>

  val And = new Step("And")

  val But = new Step("But")

  val Given = new Step("Given")

  val Then = new Step("Then")

  val When = new Step("When")

}

trait EN_SCOUSE {
  this: ScalaDsl =>

  val An = new Step("An")

  val Buh = new Step("Buh")

  val Denyousegotta = new Step("Denyousegotta")

  val Dun = new Step("Dun")

  val Givun = new Step("Givun")

  val Wun = new Step("Wun")

  val Youseknowlikewhen = new Step("Youseknowlikewhen")

  val Youseknowwhenyousegot = new Step("Youseknowwhenyousegot")

}

trait EN_AU {
  this: ScalaDsl =>

  val ButattheendofthedayIreckon = new Step("ButattheendofthedayIreckon")

  val Itsjustunbelievable = new Step("Itsjustunbelievable")

  val Tooright = new Step("Tooright")

  val Yeahnah = new Step("Yeahnah")

  val Yknow = new Step("Yknow")

}

trait EN_LOL {
  this: ScalaDsl =>

  val AN = new Step("AN")

  val BUT = new Step("BUT")

  val DEN = new Step("DEN")

  val ICANHAZ = new Step("ICANHAZ")

  val WEN = new Step("WEN")

}

trait EN_PIRATE {
  this: ScalaDsl =>

  val Avast = new Step("Avast")

  val Aye = new Step("Aye")

  val Blimey = new Step("Blimey")

  val Gangway = new Step("Gangway")

  val Letgoandhaul = new Step("Letgoandhaul")

}

trait EN_TX {
  this: ScalaDsl =>

  val Andyall = new Step("Andyall")

  val Butyall = new Step("Butyall")

  val Givenyall = new Step("Givenyall")

  val Thenyall = new Step("Thenyall")

  val Whenyall = new Step("Whenyall")

}

trait EO {
  this: ScalaDsl =>

  val Do = new Step("Do")

  val Donitaĵo = new Step("Donitaĵo")

  val Kaj = new Step("Kaj")

  val Se = new Step("Se")

  val Sed = new Step("Sed")

}

trait ES {
  this: ScalaDsl =>

  val Cuando = new Step("Cuando")

  val Dada = new Step("Dada")

  val Dadas = new Step("Dadas")

  val Dado = new Step("Dado")

  val Dados = new Step("Dados")

  val Entonces = new Step("Entonces")

  val Pero = new Step("Pero")

  val Y = new Step("Y")

}

trait ET {
  this: ScalaDsl =>

  val Eeldades = new Step("Eeldades")

  val Ja = new Step("Ja")

  val Kui = new Step("Kui")

  val Kuid = new Step("Kuid")

  val Siis = new Step("Siis")

}

trait FA {
  this: ScalaDsl =>

  val آنگاه = new Step("آنگاه")

  val اما = new Step("اما")

  val بافرض = new Step("بافرض")

  val هنگامی = new Step("هنگامی")

  val و = new Step("و")

}

trait FI {
  this: ScalaDsl =>

  val Ja = new Step("Ja")

  val Kun = new Step("Kun")

  val Mutta = new Step("Mutta")

  val Niin = new Step("Niin")

  val Oletetaan = new Step("Oletetaan")

}

trait FR {
  this: ScalaDsl =>

  val Alors = new Step("Alors")

  val Et = new Step("Et")

  val Etantdonné = new Step("Etantdonné")

  val Etantdonnée = new Step("Etantdonnée")

  val Etantdonnées = new Step("Etantdonnées")

  val Etantdonnés = new Step("Etantdonnés")

  val Lorsqu = new Step("Lorsqu")

  val Lorsque = new Step("Lorsque")

  val Mais = new Step("Mais")

  val Quand = new Step("Quand")

  val Soit = new Step("Soit")

  val Étantdonné = new Step("Étantdonné")

  val Étantdonnée = new Step("Étantdonnée")

  val Étantdonnées = new Step("Étantdonnées")

  val Étantdonnés = new Step("Étantdonnés")

}

trait HE {
  this: ScalaDsl =>

  val אבל = new Step("אבל")

  val אז = new Step("אז")

  val אזי = new Step("אזי")

  val בהינתן = new Step("בהינתן")

  val וגם = new Step("וגם")

  val כאשר = new Step("כאשר")

}

trait HI {
  this: ScalaDsl =>

  val अगर = new Step("अगर")

  val और = new Step("और")

  val चूंकि = new Step("चूंकि")

  val जब = new Step("जब")

  val तथा = new Step("तथा")

  val तब = new Step("तब")

  val पर = new Step("पर")

  val यदि = new Step("यदि")

}

trait HR {
  this: ScalaDsl =>

  val Ali = new Step("Ali")

  val I = new Step("I")

  val Kad = new Step("Kad")

  val Kada = new Step("Kada")

  val Onda = new Step("Onda")

  val Zadan = new Step("Zadan")

  val Zadani = new Step("Zadani")

  val Zadano = new Step("Zadano")

}

trait HU {
  this: ScalaDsl =>

  val Adott = new Step("Adott")

  val Akkor = new Step("Akkor")

  val Amennyiben = new Step("Amennyiben")

  val Amikor = new Step("Amikor")

  val De = new Step("De")

  val Ha = new Step("Ha")

  val Majd = new Step("Majd")

  val És = new Step("És")

}

trait ID {
  this: ScalaDsl =>

  val Dan = new Step("Dan")

  val Dengan = new Step("Dengan")

  val Ketika = new Step("Ketika")

  val Maka = new Step("Maka")

  val Tapi = new Step("Tapi")

}

trait IS {
  this: ScalaDsl =>

  val Ef = new Step("Ef")

  val En = new Step("En")

  val Og = new Step("Og")

  val Þegar = new Step("Þegar")

  val Þá = new Step("Þá")

}

trait IT {
  this: ScalaDsl =>

  val Allora = new Step("Allora")

  val Data = new Step("Data")

  val Date = new Step("Date")

  val Dati = new Step("Dati")

  val Dato = new Step("Dato")

  val E = new Step("E")

  val Ma = new Step("Ma")

  val Quando = new Step("Quando")

}

trait JA {
  this: ScalaDsl =>

  val かつ = new Step("かつ")

  val しかし = new Step("しかし")

  val ただし = new Step("ただし")

  val ならば = new Step("ならば")

  val もし = new Step("もし")

  val 但し = new Step("但し")

  val 前提 = new Step("前提")

}

trait KO {
  this: ScalaDsl =>

  val 그러면 = new Step("그러면")

  val 그리고 = new Step("그리고")

  val 단 = new Step("단")

  val 만약 = new Step("만약")

  val 만일 = new Step("만일")

  val 먼저 = new Step("먼저")

  val 조건 = new Step("조건")

  val 하지만 = new Step("하지만")

}

trait LT {
  this: ScalaDsl =>

  val Bet = new Step("Bet")

  val Duota = new Step("Duota")

  val Ir = new Step("Ir")

  val Kai = new Step("Kai")

  val Tada = new Step("Tada")

}

trait LU {
  this: ScalaDsl =>

  val a = new Step("a")

  val an = new Step("an")

  val awer = new Step("awer")

  val dann = new Step("dann")

  val mä = new Step("mä")

  val ugeholl = new Step("ugeholl")

  val wann = new Step("wann")

}

trait LV {
  this: ScalaDsl =>

  val Bet = new Step("Bet")

  val Ja = new Step("Ja")

  val Kad = new Step("Kad")

  val Tad = new Step("Tad")

  val Un = new Step("Un")

}

trait NL {
  this: ScalaDsl =>

  val Als = new Step("Als")

  val Dan = new Step("Dan")

  val En = new Step("En")

  val Gegeven = new Step("Gegeven")

  val Maar = new Step("Maar")

  val Stel = new Step("Stel")

}

trait NO {
  this: ScalaDsl =>

  val Gitt = new Step("Gitt")

  val Men = new Step("Men")

  val Når = new Step("Når")

  val Og = new Step("Og")

  val Så = new Step("Så")

}

trait PL {
  this: ScalaDsl =>

  val Ale = new Step("Ale")

  val Gdy = new Step("Gdy")

  val I = new Step("I")

  val Jeśli = new Step("Jeśli")

  val Jeżeli = new Step("Jeżeli")

  val Kiedy = new Step("Kiedy")

  val Mając = new Step("Mając")

  val Oraz = new Step("Oraz")

  val Wtedy = new Step("Wtedy")

  val Zakładając = new Step("Zakładając")

}

trait PT {
  this: ScalaDsl =>

  val Dada = new Step("Dada")

  val Dadas = new Step("Dadas")

  val Dado = new Step("Dado")

  val Dados = new Step("Dados")

  val E = new Step("E")

  val Entao = new Step("Entao")

  val Então = new Step("Então")

  val Mas = new Step("Mas")

  val Quando = new Step("Quando")

}

trait RO {
  this: ScalaDsl =>

  val Atunci = new Step("Atunci")

  val Cand = new Step("Cand")

  val Când = new Step("Când")

  val Dar = new Step("Dar")

  val Datefiind = new Step("Datefiind")

  val Datfiind = new Step("Datfiind")

  val Datifiind = new Step("Datifiind")

  val Daţifiind = new Step("Daţifiind")

  val Dațifiind = new Step("Dațifiind")

  val Si = new Step("Si")

  val Şi = new Step("Şi")

  val Și = new Step("Și")

}

trait RU {
  this: ScalaDsl =>

  val А = new Step("А")

  val Дано = new Step("Дано")

  val Допустим = new Step("Допустим")

  val Если = new Step("Если")

  val И = new Step("И")

  val Когда = new Step("Когда")

  val Ктомуже = new Step("Ктомуже")

  val Но = new Step("Но")

  val Пусть = new Step("Пусть")

  val Также = new Step("Также")

  val То = new Step("То")

  val Тогда = new Step("Тогда")

}

trait SK {
  this: ScalaDsl =>

  val A = new Step("A")

  val Ak = new Step("Ak")

  val Ale = new Step("Ale")

  val Ataktiež = new Step("Ataktiež")

  val Atiež = new Step("Atiež")

  val Azároveň = new Step("Azároveň")

  val Keď = new Step("Keď")

  val Pokiaľ = new Step("Pokiaľ")

  val Potom = new Step("Potom")

  val Tak = new Step("Tak")

  val Zapredpokladu = new Step("Zapredpokladu")

}

trait SR_CYRL {
  this: ScalaDsl =>

  val Али = new Step("Али")

  val Задате = new Step("Задате")

  val Задати = new Step("Задати")

  val Задато = new Step("Задато")

  val И = new Step("И")

  val Кад = new Step("Кад")

  val Када = new Step("Када")

  val Онда = new Step("Онда")

}

trait SR_LATN {
  this: ScalaDsl =>

  val Ali = new Step("Ali")

  val I = new Step("I")

  val Kad = new Step("Kad")

  val Kada = new Step("Kada")

  val Onda = new Step("Onda")

  val Zadate = new Step("Zadate")

  val Zadato = new Step("Zadato")

  val Zatati = new Step("Zatati")

}

trait SV {
  this: ScalaDsl =>

  val Givet = new Step("Givet")

  val Men = new Step("Men")

  val När = new Step("När")

  val Och = new Step("Och")

  val Så = new Step("Så")

}

trait TL {
  this: ScalaDsl =>

  val అప్పుడు = new Step("అప్పుడు")

  val ఈపరిస్థితిలో = new Step("ఈపరిస్థితిలో")

  val కాని = new Step("కాని")

  val చెప్పబడినది = new Step("చెప్పబడినది")

  val మరియు = new Step("మరియు")

}

trait TR {
  this: ScalaDsl =>

  val Ama = new Step("Ama")

  val Diyelimki = new Step("Diyelimki")

  val Eğerki = new Step("Eğerki")

  val Fakat = new Step("Fakat")

  val Ozaman = new Step("Ozaman")

  val Ve = new Step("Ve")

}

trait TT {
  this: ScalaDsl =>

  val Вә = new Step("Вә")

  val Ләкин = new Step("Ләкин")

  val Нәтиҗәдә = new Step("Нәтиҗәдә")

  val Һәм = new Step("Һәм")

  val Әгәр = new Step("Әгәр")

  val Әйтик = new Step("Әйтик")

  val Әмма = new Step("Әмма")

}

trait UK {
  this: ScalaDsl =>

  val І = new Step("І")

  val Але = new Step("Але")

  val Атакож = new Step("Атакож")

  val Дано = new Step("Дано")

  val Коли = new Step("Коли")

  val Нехай = new Step("Нехай")

  val Припустимо = new Step("Припустимо")

  val Припустимощо = new Step("Припустимощо")

  val Та = new Step("Та")

  val То = new Step("То")

  val Тоді = new Step("Тоді")

  val Якщо = new Step("Якщо")

}

trait UZ {
  this: ScalaDsl =>

  val Агар = new Step("Агар")

  val Аммо = new Step("Аммо")

  val Бирок = new Step("Бирок")

  val Ва = new Step("Ва")

  val Лекин = new Step("Лекин")

  val Унда = new Step("Унда")

}

trait VI {
  this: ScalaDsl =>

  val Biết = new Step("Biết")

  val Cho = new Step("Cho")

  val Khi = new Step("Khi")

  val Nhưng = new Step("Nhưng")

  val Thì = new Step("Thì")

  val Và = new Step("Và")

}

trait ZH_CN {
  this: ScalaDsl =>

  val 但是 = new Step("但是")

  val 假如 = new Step("假如")

  val 假定 = new Step("假定")

  val 假设 = new Step("假设")

  val 同时 = new Step("同时")

  val 并且 = new Step("并且")

  val 当 = new Step("当")

  val 而且 = new Step("而且")

  val 那么 = new Step("那么")

}

trait ZH_TW {
  this: ScalaDsl =>

  val 並且 = new Step("並且")

  val 但是 = new Step("但是")

  val 假如 = new Step("假如")

  val 假定 = new Step("假定")

  val 假設 = new Step("假設")

  val 同時 = new Step("同時")

  val 當 = new Step("當")

  val 而且 = new Step("而且")

  val 那麼 = new Step("那麼")

}
